@@ -1,7 +1,7 @@
 from rest_framework import serializers
 
 from netbox.api.serializers import WritableNestedSerializer
-from netbox_storage.models import Filesystem, Drive, Partition, LinuxVolume
+from netbox_storage.models import Filesystem, Drive, Partition, MountedVolume
 
 
 #
@@ -47,11 +47,11 @@ class NestedPartitionSerializer(WritableNestedSerializer):
 #
 # Linux Volume
 #
-class NestedLinuxVolumeSerializer(WritableNestedSerializer):
+class NestedMountedVolumeSerializer(WritableNestedSerializer):
     url = serializers.HyperlinkedIdentityField(
-        view_name="plugins-api:netbox_storage-api:linuxvolume-detail"
+        view_name="plugins-api:netbox_storage-api:mountedvolume-detail"
     )
 
     class Meta:
-        model = LinuxVolume
+        model = MountedVolume
         fields = ["id", "url", "display", "size", "path"]
\ No newline at end of file
