@@ -1,7 +1,7 @@
 from django.core.validators import MinValueValidator
 from django.forms import (
     CharField,
-    FloatField, CheckboxInput,
+    FloatField
 )
 from django.urls import reverse_lazy
 
@@ -170,11 +170,6 @@ class LinuxVolumeTemplateForm(NetBoxModelForm):
         label="Description",
         help_text="Short Description e.g. Hard Drive 1 on SSD Cluster",
     )
-    new_drive = CheckboxInput(
-        required=False,
-        label="Description",
-        help_text="Short Description e.g. Hard Drive 1 on SSD Cluster",
-    )
 
     fieldsets = (
         (
@@ -192,7 +187,6 @@ class LinuxVolumeTemplateForm(NetBoxModelForm):
                 "path",
                 "fs",
                 "description",
-                "new_drive"
             ),
         ),
     )
@@ -230,6 +224,60 @@ class LinuxVolumeTemplateForm(NetBoxModelForm):
         return template_configuration
 
 
+class DriveTemplateForm(NetBoxModelForm):
+    size = FloatField(
+        label="Size (GB)",
+        help_text="The size of the logical volume e.g. 25",
+        validators=[MinValueValidator(0.1)],
+    )
+    cluster_type = DynamicModelChoiceField(
+        queryset=ClusterType.objects.all(),
+        help_text="The Cluster Type of the drive",
+    )
+    cluster = DynamicModelChoiceField(
+        queryset=Cluster.objects.all(),
+        query_params={
+            'type_id': '$cluster_type'  # ClusterType.objects.filter(name="Storage").values_list('id', flat=True)[0]
+        },
+        help_text="The Storage Cluster of the drive",
+    )
+    platform = DynamicModelChoiceField(
+        queryset=Platform.objects.all(),
+        help_text="Mapping between Volume and platform e.g. Rocky Linux 8",
+    )
+
+    fieldsets = (
+        (
+            "Drive Config",
+            (
+                "cluster_type",
+                "cluster",
+                "size",
+                "platform",
+            ),
+        ),
+    )
+
+    class Meta:
+        model = TemplateConfigurationLinuxVolume
+        fields = [
+            "platform",
+        ]
+
+    def save(self, *args, **kwargs):
+        drive = Drive.objects.create(cluster=self.cleaned_data['cluster'], size=self.cleaned_data['size'])
+        self.instance.drive = drive
+        template_configuration = super().save(*args, **kwargs)
+
+        print(f"{self.cleaned_data['size']}")
+
+        print("Instances")
+        print(drive)
+        print(template_configuration)
+
+        return template_configuration
+
+
 class VolumeSimpleForm(NetBoxModelForm):
     """Form for creating a new Drive object."""
     # ct = ClusterType.objects.filter(name="Storage").values_list('id', flat=True)[0]
