@@ -249,10 +249,10 @@ class Migration(migrations.Migration):
                  models.ForeignKey(blank=True, null=True, on_delete=models.deletion.CASCADE,
                                    related_name="platform_template_configuration",
                                    to="dcim.platform")),
-                ("linux_volume",
+                ("drive",
                  models.ForeignKey(blank=True, null=True, on_delete=models.deletion.CASCADE,
-                                   related_name='linux_volume_template_configuration',
-                                   to='netbox_storage.mountedvolume')),
+                                   related_name='drive_template_configuration',
+                                   to='netbox_storage.drive')),
             ],
         ),
     ]
