@@ -47,9 +47,11 @@ class TemplateVolumeConfig(PluginTemplateExtension):
         obj = self.context.get("object")
 
         lv = LogicalVolume.objects.all()
-        template_linux_volumes = TemplateConfigurationLinuxVolume.objects.filter(platform=obj)
-        for tlv in template_linux_volumes:
-            tlv.linux_volume.device.drive
+        drives = TemplateConfigurationLinuxVolume.objects.filter(platform=obj).values_list('drive')
+        print("template content")
+        print(drives)
+        for d in drives:
+            print(d)
 
 
         # storage_configuration = StorageConfigurationLinuxVolume.objects.filter(virtual_machine=obj)
@@ -57,7 +59,7 @@ class TemplateVolumeConfig(PluginTemplateExtension):
         return self.render(
             "netbox_storage/inc/template_box.html",
             extra_context={
-                "template_linux_volumes": template_linux_volumes,
+                "template_linux_volumes": drives,
             }
         )
 
