@@ -40,7 +40,7 @@ from netbox_storage.views import (
     MountedVolumeView,
     MountedVolumeDeleteView, LVMAddSimpleView, AddSimpleLinuxVolumeView,
 )
-from netbox_storage.views.template import LVMAddTemplateView, AddTemplateVolumeView
+from netbox_storage.views.template import LVMAddTemplateView, AddTemplateVolumeView, AddTemplateDriveView
 
 app_name = "netbox_storage"
 
@@ -123,5 +123,6 @@ urlpatterns = [
     # Template Configuration
     #
     path('template-lvm-add/', LVMAddTemplateView.as_view(), name='template_lvm_add'),
-    path('template-volume-add/', AddTemplateVolumeView.as_view(), name="template_volume_add")
+    path('template-volume-add/', AddTemplateVolumeView.as_view(), name="template_volume_add"),
+    path('template-drive-add/', AddTemplateDriveView.as_view(), name='template_drive_add')
 ]
